@@ -18,14 +18,29 @@ def repack_objects(base_path: Path) -> List[Dict[str, Any]]:
             raise Exception("Objects must be directories")
         obj = json.loads(path.joinpath("object.json").read_text())
         obj["GUID"] = guid
+
         script_path = path.joinpath("script.lua")
         if script_path.exists():
             obj["LuaScript"] = script_path.read_text()
         else:
             obj["LuaScript"] = ""
+
         if path.joinpath("contained").is_dir():
             obj["ContainedObjects"] = repack_objects(path.joinpath("contained"))
 
+        script_state_path = path.joinpath("script-state.json")
+        if script_state_path.exists():
+            script_state = json.loads(script_state_path.read_text())
+            obj["LuaScriptState"] = json.dumps(script_state)
+        else:
+            obj["LuaScriptState"] = ""
+
+        xml_ui_path = path.joinpath("ui.xml")
+        if xml_ui_path.exists():
+            obj["XmlUI"] = xml_ui_path.read_text()
+        else:
+            obj["XmlUI"] = ""
+
         objects.append(obj)
     return objects
 
