@@ -7,4 +7,4 @@ def to_unix(text: str) -> str:
 
 
 def format_json(value: Dict[Any, Any]) -> str:
-    return json.dumps(value, indent=2, separators=(",", ": "))
+    return json.dumps(value, indent=2, separators=(",", ": ")) + "\n"
